==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Anàs suprimà touti li firma d’aquela peticioun. Sias segur de voulé countinuà ?',
	'aucune_signature' => 'Mìnga firma',

	// B
	'bouton_checkbox_envoi_message' => 'poussibilità de mandà un message',
	'bouton_checkbox_indiquer_site' => 'endicà oubligatoriamen un sit web',
	'bouton_checkbox_signature_unique_email' => 'una firma souleta per adressa e-mail',
	'bouton_checkbox_signature_unique_site' => 'una firma souleta per sit web',
	'bouton_radio_activer_petition' => 'Ativà la peticioun',
	'bouton_radio_pas_petition' => 'Mìnga peticioun',
	'bouton_radio_petition_activee' => 'Peticioun ativada',
	'bouton_radio_supprimer_petition' => 'Suprimà la peticioun',

	// F
	'filtre' => 'Filtre :',
	'form_pet_adresse_site' => 'Adressa URL dóu vouòstre sit',
	'form_pet_aucune_signature' => 'Mìnga firma courrespouònde en aqueu code…',
	'form_pet_confirmation' => 'Vourguès counfirmà la vouòstra firma :',
	'form_pet_deja_signe' => 'Avès jà firmat aqueu tèstou.',
	'form_pet_envoi_mail_confirmation' => 'Un courrié eletrònicou de counfirmacioun ven d’estre mandat a @email@. Vi deurès visità l’adressa web menciounada en aqueu courrié da validà la vouòstra firma.',
	'form_pet_mail_confirmation' => 'Bouònjou,

Avès demandat da firmà la peticioun :
@titre@.

Avès fournit li infourmacioun seguenti :
    Noum : @nom_email@
    Sit : @nom_site@ - @url_site@
    @message@

IMPOURTANT...
Da validà la vouòstra firma, basta vi counetà a l’adressa aquì souta (en lou cas countrari, la vouòstra demanda serà refudada) :

    @url@


Mercì de la vouòstra participacioun
',
	'form_pet_message_commentaire' => 'Un message, un coumentari ?',
	'form_pet_nom_site2' => 'Noum dóu vouòstre  sit web', # enlever le gras
	'form_pet_probleme_liens' => 'Vourguès revirà lou vouòstre message en suprimant lu estac ipertèst.',
	'form_pet_probleme_technique' => 'Proublèma tècnicou, li firma seràn tempourariamen souspendut.',
	'form_pet_signature_validee' => 'La vouòstra firma es validada. Mercì !',
	'form_pet_site_deja_enregistre' => 'Aqueu sit es jà registrat',
	'form_pet_url_invalide' => 'L’URL qu’avès endicat noun es vàlidou.',
	'form_pet_votre_email' => 'La vouòstra adressa e-mail',
	'form_pet_votre_nom' => 'Lou vouòstre noum',
	'form_pet_votre_site' => 'S’avès un sit Web, poudès l’endicà aquì souta',

	// I
	'icone_relancer_signataire' => 'Ensègre lou signatàri',
	'icone_relancer_signataires' => 'Ensègre lu signatàri',
	'icone_suivi_petitions' => 'Sègre/gerà li peticioun',
	'icone_supprimer_signature' => 'Suprimà aquela firma',
	'icone_supprimer_signatures' => 'Suprimà li firma',
	'icone_valider_signature' => 'Validà aquela firma',
	'icone_valider_signatures' => 'Validà li firma',
	'info_adresse_email' => 'ADRESSA E-MAIL :',
	'info_fonctionnement_petition' => 'Founciounamen de la peticioun :',
	'info_signature_supprimee' => 'Firma suprimada',
	'info_signature_supprimee_erreur' => 'Errour : aqueu code de supressioun courrespouònde a mìnga firma',
	'info_site_web' => 'SIT WEB :',
	'info_texte_message' => 'Tèst dóu vouòstre message :',

	// L
	'lien_reponse_article' => 'Respouòsta a l’article',

	// N
	'nombre_signatures' => '@nb@ firma',

	// S
	'sans_nom' => 'Anounime',
	'signatures_article' => 'Firma de l’article :',
	'signatures_aucune' => 'Mìnga',
	'signatures_meme_auteur' => 'Li firma dau meme autour',
	'signatures_meme_site' => 'Li firma embé lou meme sit',
	'signatures_poubelle' => 'Suprimadi',
	'signatures_prop' => 'En aspèra',
	'signatures_publie' => 'Counfirmadi',
	'signatures_recherche_label' => 'Recercà dei firma :',
	'signatures_selection' => 'Seleciounà li firma :',
	'signatures_toutes' => 'Touti',
	'statut_poubelle' => 'Suprimada',
	'statut_prop' => 'En aspera de validacioun',
	'statut_publie' => 'Counfirmada',

	// T
	'texte_descriptif_petition' => 'Descritiéu de la peticioun',
	'titre_page_controle_petition' => 'Seguit dei peticioun',
	'titre_petition' => 'Peticioun',
	'titre_petitions' => 'Peticioun',
	'titre_selection_action' => 'Selecioun',
	'titre_signatures_attente' => 'Firma en aspera de validacioun',
	'titre_signatures_publie' => 'Firma counfirmadi',
	'titre_suivi_petition' => 'Seguit dei peticioun',
	'tout_voir' => 'Veire touti li firma',

	// U
	'une_signature' => '1 firma',

	// V
	'voir_signatures_objet' => 'Veire li firma'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Anàs suprimà touti li firma d’aquela peticioun. Sias segur de voulé countinuà ?',
	'aucune_signature' => 'Mìnga firma',

	// B
	'bouton_checkbox_envoi_message' => 'poussibilità de mandà un message',
	'bouton_checkbox_indiquer_site' => 'endicà oubligatoriamen un sit web',
	'bouton_checkbox_signature_unique_email' => 'una firma souleta per adressa e-mail',
	'bouton_checkbox_signature_unique_site' => 'una firma souleta per sit web',
	'bouton_radio_activer_petition' => 'Ativà la peticioun',
	'bouton_radio_pas_petition' => 'Mìnga peticioun',
	'bouton_radio_petition_activee' => 'Peticioun ativada',
	'bouton_radio_supprimer_petition' => 'Suprimà la peticioun',

	// F
	'filtre' => 'Filtre :',
	'form_pet_adresse_site' => 'Adressa URL dóu vouòstre sit',
	'form_pet_aucune_signature' => 'Mìnga firma courrespouònde en aqueu code…',
	'form_pet_confirmation' => 'Vourguès counfirmà la vouòstra firma :',
	'form_pet_deja_signe' => 'Avès jà firmat aqueu tèstou.',
	'form_pet_envoi_mail_confirmation' => 'Un courrié eletrònicou de counfirmacioun ven d’estre mandat a @email@. Vi deurès visità l’adressa web menciounada en aqueu courrié da validà la vouòstra firma.',
	'form_pet_mail_confirmation' => 'Bouònjou,

Avès demandat da firmà la peticioun :
@titre@.

Avès fournit li infourmacioun seguenti :
    Noum : @nom_email@
    Sit : @nom_site@ - @url_site@
    @message@

IMPOURTANT...
Da validà la vouòstra firma, basta vi counetà a l’adressa aquì souta (en lou cas countrari, la vouòstra demanda serà refudada) :

    @url@


Mercì de la vouòstra participacioun
',
	'form_pet_message_commentaire' => 'Un message, un coumentari ?',
	'form_pet_nom_site2' => 'Noum dóu vouòstre  sit web', # enlever le gras
	'form_pet_probleme_liens' => 'Vourguès revirà lou vouòstre message en suprimant lu estac ipertèst.',
	'form_pet_probleme_technique' => 'Proublèma tècnicou, li firma seràn tempourariamen souspendut.',
	'form_pet_signature_validee' => 'La vouòstra firma es validada. Mercì !',
	'form_pet_site_deja_enregistre' => 'Aqueu sit es jà registrat',
	'form_pet_url_invalide' => 'L’URL qu’avès endicat noun es vàlidou.',
	'form_pet_votre_email' => 'La vouòstra adressa e-mail',
	'form_pet_votre_nom' => 'Lou vouòstre noum',
	'form_pet_votre_site' => 'S’avès un sit Web, poudès l’endicà aquì souta',

	// I
	'icone_relancer_signataire' => 'Ensègre lou signatàri',
	'icone_relancer_signataires' => 'Ensègre lu signatàri',
	'icone_suivi_petitions' => 'Sègre/gerà li peticioun',
	'icone_supprimer_signature' => 'Suprimà aquela firma',
	'icone_supprimer_signatures' => 'Suprimà li firma',
	'icone_valider_signature' => 'Validà aquela firma',
	'icone_valider_signatures' => 'Validà li firma',
	'info_adresse_email' => 'ADRESSA E-MAIL :',
	'info_fonctionnement_petition' => 'Founciounamen de la peticioun :',
	'info_signature_supprimee' => 'Firma suprimada',
	'info_signature_supprimee_erreur' => 'Errour : aqueu code de supressioun courrespouònde a mìnga firma',
	'info_site_web' => 'SIT WEB :',
	'info_texte_message' => 'Tèst dóu vouòstre message :',

	// L
	'lien_reponse_article' => 'Respouòsta a l’article',

	// N
	'nombre_signatures' => '@nb@ firma',

	// S
	'sans_nom' => 'Anounime',
	'signatures_article' => 'Firma de l’article :',
	'signatures_aucune' => 'Mìnga',
	'signatures_meme_auteur' => 'Li firma dau meme autour',
	'signatures_meme_site' => 'Li firma emb’au meme sit',
	'signatures_poubelle' => 'Suprimadi',
	'signatures_prop' => 'En aspèra',
	'signatures_publie' => 'Counfirmadi',
	'signatures_recherche_label' => 'Recercà dei firma :',
	'signatures_selection' => 'Seleciounà li firma :',
	'signatures_toutes' => 'Touti',
	'statut_poubelle' => 'Suprimada',
	'statut_prop' => 'En aspera de validacioun',
	'statut_publie' => 'Counfirmada',

	// T
	'texte_descriptif_petition' => 'Descritiéu de la peticioun',
	'titre_page_controle_petition' => 'Seguit dei peticioun',
	'titre_petition' => 'Peticioun',
	'titre_petitions' => 'Peticioun',
	'titre_selection_action' => 'Selecioun',
	'titre_signatures_attente' => 'Firma en aspera de validacioun',
	'titre_signatures_publie' => 'Firma counfirmadi',
	'titre_suivi_petition' => 'Seguit dei peticioun',
	'tout_voir' => 'Veire touti li firma',

	// U
	'une_signature' => '1 firma',

	// V
	'voir_signatures_objet' => 'Veire li firma'
);

?>
